var countries = require('./util/countries.js');

// Configuration file for EEA Elasticsearch River Plugin
// check
// https://github.com/eea/eea.elasticsearch.river.rdf/blob/master/README.rst
// to see how the configration options work
// Please do not edit this file directly on production servers

// Properties that are indexed into ElasticSearch
var proplist = [
    "http://purl.org/dc/terms/spatial",
    "http://purl.org/dc/terms/creator",
    "http://www.w3.org/1999/02/22-rdf-syntax-ns#type",
    "http://purl.org/dc/terms/issued",
    "http://purl.org/dc/terms/expires",
    "http://purl.org/dc/terms/modified",
    "http://purl.org/dc/terms/title",
    "http://www.w3.org/1999/02/22-rdf-syntax-ns#about",
    "language",
    "http://www.eea.europa.eu/portal_types#topic",
    "http://purl.org/dc/terms/description",
    "http://www.eea.europa.eu/ontologies.rdf#hasWorkflowState",
    "http://www.eea.europa.eu/ontologies.rdf#objectProvides"];
var listtype = "white";

// Normalise the properties to the given value
var normalisedProperties = {
    "http://www.eea.europa.eu/portal_workflow/daviz_workflow/states/published" : "published",
    "http://www.eea.europa.eu/portal_workflow/eea_simple_approval/states/published": "published",
    "http://www.eea.europa.eu/portal_workflow/one_state_workflow/states/published": "published",
    "http://www.eea.europa.eu/portal_workflow/eea_simple_public_approval/states/published": "published",
    "http://www.eea.europa.eu/portal_workflow/indicators_workflow/states/published": "published",
    "http://www.eea.europa.eu/portal_workflow/folder_workflow/states/published": "published",
    "http://www.eea.europa.eu/portal_workflow/plone_workflow/states/published": "published",
    "http://www.eea.europa.eu/portal_workflow/linguaflow/states/published": "published",
    "http://www.eea.europa.eu/portal_workflow/eea_default_workflow/states/published": "published",
    "http://www.eea.europa.eu/portal_workflow/eea_data_workflow/states/published": "published"
};

// Do not index these values for a given properties
var blackMap = {
    "http://www.w3.org/1999/02/22-rdf-syntax-ns#type" : [
        "Webpage",
        "Tracked file",
        "http://www.w3.org/ns/dcat#Dataset",
        "http://www.w3.org/ns/dcat#Distribution" ]
};

// Index _only_ these values for given properties
var whiteMap = { "http://purl.org/dc/terms/spatial" : countries.countries };

// Normalise these following objects to a given value
var normObj = {
    "Organisation" : "Organization",
    "Czechia" : "Czech Republic",
    "Russia" : "Russian Federation",
    "Kosovo (UNSCR 1244/99)" : "Kosovo",
    "Macedonia (FYR)" : "Macedonia",
    "Default" : "Various other issues",
    "Collection - old style" : "Collection",
    "http://www.eea.europa.eu/portal_vocabularies/themes/acidification" : "Air pollution",
    "http://www.eea.europa.eu/portal_vocabularies/themes/air_quality" : "Air pollution",
    "http://www.eea.europa.eu/portal_vocabularies/themes/nature" : "Biodiversity",
    "http://www.eea.europa.eu/portal_vocabularies/themes/ozone" : "Climate change",
    "http://www.eea.europa.eu/portal_vocabularies/themes/management" : "Policy instruments",
    "http://www.eea.europa.eu/portal_vocabularies/themes/information" : "Policy instruments",
    "http://www.eea.europa.eu/portal_vocabularies/themes/reporting" : "Policy instruments",
    "http://www.eea.europa.eu/portal_vocabularies/themes/population" : "Green economy",
    "http://www.eea.europa.eu/portal_vocabularies/themes/health" : "Environment and health",
    "http://www.eea.europa.eu/portal_workflow/daviz_workflow/states/published" : "published",
    "http://www.eea.europa.eu/portal_workflow/eea_simple_approval/states/published": "published",
    "http://www.eea.europa.eu/portal_workflow/one_state_workflow/states/published": "published",
    "http://www.eea.europa.eu/portal_workflow/eea_simple_public_approval/states/published": "published",
    "http://www.eea.europa.eu/portal_workflow/indicators_workflow/states/published": "published",
    "http://www.eea.europa.eu/portal_workflow/folder_workflow/states/published": "published",
    "http://www.eea.europa.eu/portal_workflow/plone_workflow/states/published": "published",
    "http://www.eea.europa.eu/portal_workflow/linguaflow/states/published": "published",
    "http://www.eea.europa.eu/portal_workflow/eea_default_workflow/states/published": "published",
    "http://www.eea.europa.eu/portal_workflow/eea_data_workflow/states/published": "published"
};

// Normalise missing properties with the given values
var normMissing = {
    "http://purl.org/dc/terms/spatial": "Other",
    "http://www.eea.europa.eu/portal_types#topic": "Various other issues"
};

// RDF endpoint to query
var endpoint = 'http://semantic.eea.europa.eu/sparql';

// Query used for initial index
var queryType = 'construct';
var indexQuery = [
        "CONSTRUCT {?s ?p ?o} WHERE { graph ?g { ?s ?p ?o } . FILTER (str(?g) = concat(str(?s),\"/@@rdf\")) . ?s a <http://www.eea.europa.eu/portal_types/Article#Article> . ?s ?p ?o }",
        "CONSTRUCT {?s ?p ?o} WHERE { graph ?g { ?s ?p ?o } . FILTER (str(?g) = concat(str(?s),\"/@@rdf\")) . ?s a <http://www.eea.europa.eu/portal_types/Assessment#Assessment> . ?s ?p ?o }",
        "CONSTRUCT {?s ?p ?o} WHERE { graph ?g { ?s ?p ?o } . FILTER (str(?g) = concat(str(?s),\"/@@rdf\")) . ?s a <http://www.eea.europa.eu/portal_types/CloudVideo#CloudVideo> . ?s ?p ?o }",
        "CONSTRUCT {?s ?p ?o} WHERE { graph ?g { ?s ?p ?o } . FILTER (str(?g) = concat(str(?s),\"/@@rdf\")) . ?s a <http://www.eea.europa.eu/portal_types/Data#Data> . ?s ?p ?o }",
        "CONSTRUCT {?s ?p ?o} WHERE { graph ?g { ?s ?p ?o } . FILTER (str(?g) = concat(str(?s),\"/@@rdf\")) . ?s a <http://www.eea.europa.eu/portal_types/EEAFigure#EEAFigure> . ?s ?p ?o }",
        "CONSTRUCT {?s ?p ?o} WHERE { graph ?g { ?s ?p ?o } . FILTER (str(?g) = concat(str(?s),\"/@@rdf\")) . ?s a <http://www.eea.europa.eu/portal_types/DavizVisualization#DavizVisualization> . ?s ?p ?o }",
        "CONSTRUCT {?s ?p ?o} WHERE { graph ?g { ?s ?p ?o } . FILTER (str(?g) = concat(str(?s),\"/@@rdf\")) . ?s a <http://www.eea.europa.eu/portal_types/EcoTip#EcoTip> . ?s ?p ?o }",
        "CONSTRUCT {?s ?p ?o} WHERE { graph ?g { ?s ?p ?o } . FILTER (str(?g) = concat(str(?s),\"/@@rdf\")) . ?s a <http://www.eea.europa.eu/portal_types/GIS%20Application#GISApplication> . ?s ?p ?o }",
        "CONSTRUCT {?s ?p ?o} WHERE { graph ?g { ?s ?p ?o } . FILTER (str(?g) = concat(str(?s),\"/@@rdf\")) . ?s a <http://www.eea.europa.eu/portal_types/Highlight#Highlight> . ?s ?p ?o }",
        "CONSTRUCT {?s ?p ?o} WHERE { graph ?g { ?s ?p ?o } . FILTER (str(?g) = concat(str(?s),\"/@@rdf\")) . ?s a <http://www.eea.europa.eu/portal_types/KeyMessage#KeyMessage>}",
        "CONSTRUCT {?s ?p ?o} WHERE { graph ?g { ?s ?p ?o } . FILTER (str(?g) = concat(str(?s),\"/@@rdf\")) . ?s a <http://www.eea.europa.eu/portal_types/PolicyQuestion#PolicyQuestion> . ?s ?p ?o }",
        "CONSTRUCT {?s ?p ?o} WHERE { graph ?g { ?s ?p ?o } . FILTER (str(?g) = concat(str(?s),\"/@@rdf\")) . ?s a <http://www.eea.europa.eu/portal_types/PressRelease#PressRelease> . ?s ?p ?o }",
        "CONSTRUCT {?s ?p ?o} WHERE { graph ?g { ?s ?p ?o } . FILTER (str(?g) = concat(str(?s),\"/@@rdf\")) . ?s a <http://www.eea.europa.eu/portal_types/Report#Report> . ?s ?p ?o }",
        "CONSTRUCT {?s ?p ?o} WHERE { graph ?g { ?s ?p ?o } . FILTER (str(?g) = concat(str(?s),\"/@@rdf\")) . ?s a <http://www.eea.europa.eu/portal_types/SOERKeyFact#SOERKeyFact> . ?s ?p ?o }",
        "CONSTRUCT {?s ?p ?o} WHERE { graph ?g { ?s ?p ?o } . FILTER (str(?g) = concat(str(?s),\"/@@rdf\")) . ?s a <http://www.eea.europa.eu/portal_types/Fiche#Fiche> . ?s ?p ?o }",
        "CONSTRUCT {?s ?p ?o} WHERE { graph ?g { ?s ?p ?o } . FILTER (str(?g) = concat(str(?s),\"/@@rdf\")) . ?s a <http://www.eea.europa.eu/portal_types/Folder#Folder> . ?s ?p ?o }",
        "CONSTRUCT {?s ?p ?o} WHERE { graph ?g { ?s ?p ?o } . FILTER (str(?g) = concat(str(?s),\"/@@rdf\")) . ?s a <http://www.eea.europa.eu/portal_types/SOERMessage#SOERMessage> . ?s ?p ?o }"];

// Sync conditions
var syncConditions = [
    "{?resource a <http://www.eea.europa.eu/portal_types/Infographic#Infographic> } UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/Sparql#Sparql> } UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/Topic#Topic> } UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/Collection#Collection> } UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/Folder#Folder> } UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/Fiche#Fiche> } UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/Article#Article> } UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/Assessment#Assessment>} UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/AssessmentAssessmentPart#AssessmentPart>} UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/CloudVideo#CloudVideo>} UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/Data#Data>} UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/DataFile#DataFile>} UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/DavizVisualization#DavizVisualization>} UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/Document#Document>} UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/EEAFigure#EEAFigure>} UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/EEAFigureFile#EEAFigureFile>} UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/EEAVacancy#EEAVacancy>} UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/EcoTip#EcoTip>} UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/EpubFile#EpubFile>} UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/Event#Event>} UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/ExternalDataSpec#ExternalDataSpec>} UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/EyewitnessStory#EyewitnessStory>} UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/FactSheetDocument#FactSheetDocument>} UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/File#File>} UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/GIS%20Application#GISApplication>} UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/Highlight#Highlight>} UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/Image#Image>} UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/IndicatorFactSheet#IndicatorFactSheet>} UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/KeyMessage#KeyMessage>} UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/Link#Link>} UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/MethodologyReference#MethodologyReference>} UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/Organisation#Organisation>} UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/PolicyDocumentReference#PolicyDocumentReference>} UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/PolicyQuestion#PolicyQuestion>} UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/PressRelease#PressRelease>} UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/Promotion#Promotion>} UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/QuickEvent#QuickEvent>} UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/RationaleReference#RationaleReference>} UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/Report#Report>} UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/SOERKeyFact#SOERKeyFact>} UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/SOERMEssage#SOERMEssage>} UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/Specification#Specification>} UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/Speech#Speech>} UNION ",
    "{?resource a <http://www.eea.europa.eu/portal_types/WorkItem#WorkItem>}"].join('');

var syncTimeProp = "http://cr.eionet.europa.eu/ontologies/contreg.rdf#lastRefreshed";

 
module.exports = {
    'proplist': proplist,
    'listtype': listtype,
    'normalisedProperties': normalisedProperties,
    'blackMap': blackMap,
    'whiteMap': whiteMap,
    'normObj': normObj,
    'normMissing': normMissing,
    'queryType': queryType,
    'indexQuery': indexQuery,
    'endpoint': endpoint,
    'syncConditions': syncConditions,
    'syncTimeProp': syncTimeProp
};
